Changelog
=========


0.5 (2015-08-27)
----------------

- Code cleanup.
  [maurits]


0.4 (2013-09-24)
----------------

- Moved to github.  Cleanup a bit.
  [maurits]


0.3 (2012-10-30)
----------------

- better display of the buttons in the left panel. [vincent]


0.2 (2011-12-15)
----------------

- Added possibility to set custom CSS class to the subpage.  By
  default, it has the class 'mcp_widget_XXX' where XXX is the widget
  id. [vincent]


0.1 (2011-02-25)
----------------

- Initial release.
  [vincent]
